@@ -1,8 +1,7 @@
 package WWW::Hetzner::Cloud::API::LoadBalancers;
-our $AUTHORITY = 'cpan:GETTY';
 # ABSTRACT: Hetzner Cloud Load Balancers API
 
-our $VERSION = '0.002';
+our $VERSION = '0.003';
 
 use Moo;
 use Carp qw(croak);
@@ -153,6 +152,7 @@ sub detach_from_network {
     });
 }
 
+
 1;
 
 __END__
@@ -167,7 +167,7 @@ WWW::Hetzner::Cloud::API::LoadBalancers - Hetzner Cloud Load Balancers API
 
 =head1 VERSION
 
-version 0.002
+version 0.003
 
 =head1 SYNOPSIS
 
@@ -292,6 +292,20 @@ Attach load balancer to a network.
 
 Detach load balancer from a network.
 
+=head1 SEE ALSO
+
+=over 4
+
+=item * L<WWW::Hetzner::Cloud> - Main Cloud API client
+
+=item * L<WWW::Hetzner::Cloud::LoadBalancer> - LoadBalancer entity class
+
+=item * L<WWW::Hetzner::CLI::Cmd::LoadBalancer> - LoadBalancer CLI commands
+
+=item * L<WWW::Hetzner> - Main umbrella module
+
+=back
+
 =head1 SUPPORT
 
 =head2 Issues
