@@ -1,8 +1,7 @@
 package WWW::Hetzner::Cloud::API::PrimaryIPs;
-our $AUTHORITY = 'cpan:GETTY';
 # ABSTRACT: Hetzner Cloud Primary IPs API
 
-our $VERSION = '0.002';
+our $VERSION = '0.003';
 
 use Moo;
 use Carp qw(croak);
@@ -126,6 +125,7 @@ sub change_dns_ptr {
     });
 }
 
+
 1;
 
 __END__
@@ -140,7 +140,7 @@ WWW::Hetzner::Cloud::API::PrimaryIPs - Hetzner Cloud Primary IPs API
 
 =head1 VERSION
 
-version 0.002
+version 0.003
 
 =head1 SYNOPSIS
 
@@ -232,6 +232,20 @@ Unassign primary IP from resource.
 
 Change reverse DNS pointer for the primary IP.
 
+=head1 SEE ALSO
+
+=over 4
+
+=item * L<WWW::Hetzner::Cloud> - Main Cloud API client
+
+=item * L<WWW::Hetzner::Cloud::PrimaryIP> - PrimaryIP entity class
+
+=item * L<WWW::Hetzner::CLI::Cmd::PrimaryIp> - PrimaryIP CLI commands
+
+=item * L<WWW::Hetzner> - Main umbrella module
+
+=back
+
 =head1 SUPPORT
 
 =head2 Issues
