@@ -1,8 +1,7 @@
 package WWW::Hetzner::Cloud::Datacenter;
-our $AUTHORITY = 'cpan:GETTY';
 # ABSTRACT: Hetzner Cloud Datacenter object
 
-our $VERSION = '0.002';
+our $VERSION = '0.003';
 
 use Moo;
 use namespace::clean;
@@ -40,7 +39,8 @@ sub data {
 }
 
 
-1;
+
+1.
 
 __END__
 
@@ -54,7 +54,7 @@ WWW::Hetzner::Cloud::Datacenter - Hetzner Cloud Datacenter object
 
 =head1 VERSION
 
-version 0.002
+version 0.003
 
 =head1 SYNOPSIS
 
@@ -93,6 +93,22 @@ Location name (convenience accessor).
 
 Returns all datacenter data as a hashref (for JSON serialization).
 
+=head1 SEE ALSO
+
+=over 4
+
+=item * L<WWW::Hetzner::Cloud::API::Datacenters> - Datacenters API
+
+=item * L<WWW::Hetzner::Cloud> - Main Cloud API client
+
+=item * L<WWW::Hetzner::Cloud::Server> - Server entity
+
+=item * L<WWW::Hetzner::Cloud::Location> - Location entity
+
+=item * L<WWW::Hetzner> - Main umbrella module
+
+=back
+
 =head1 SUPPORT
 
 =head2 Issues
