@@ -1,8 +1,7 @@
 package WWW::Hetzner::Cloud::Firewall;
-our $AUTHORITY = 'cpan:GETTY';
 # ABSTRACT: Hetzner Cloud Firewall object
 
-our $VERSION = '0.002';
+our $VERSION = '0.003';
 
 use Moo;
 use Carp qw(croak);
@@ -118,7 +117,8 @@ sub data {
 }
 
 
-1;
+
+1.
 
 __END__
 
@@ -132,7 +132,7 @@ WWW::Hetzner::Cloud::Firewall - Hetzner Cloud Firewall object
 
 =head1 VERSION
 
-version 0.002
+version 0.003
 
 =head1 SYNOPSIS
 
@@ -232,6 +232,20 @@ Reloads firewall data from the API.
 
 Returns all firewall data as a hashref (for JSON serialization).
 
+=head1 SEE ALSO
+
+=over 4
+
+=item * L<WWW::Hetzner::Cloud::API::Firewalls> - Firewalls API
+
+=item * L<WWW::Hetzner::Cloud> - Main Cloud API client
+
+=item * L<WWW::Hetzner::Cloud::Server> - Server entity
+
+=item * L<WWW::Hetzner> - Main umbrella module
+
+=back
+
 =head1 SUPPORT
 
 =head2 Issues
