@@ -1,8 +1,7 @@
 package WWW::Hetzner::Cloud::Image;
-our $AUTHORITY = 'cpan:GETTY';
 # ABSTRACT: Hetzner Cloud Image object
 
-our $VERSION = '0.002';
+our $VERSION = '0.003';
 
 use Moo;
 use namespace::clean;
@@ -70,7 +69,8 @@ sub data {
 }
 
 
-1;
+
+1.
 
 __END__
 
@@ -84,7 +84,7 @@ WWW::Hetzner::Cloud::Image - Hetzner Cloud Image object
 
 =head1 VERSION
 
-version 0.002
+version 0.003
 
 =head1 SYNOPSIS
 
@@ -157,6 +157,20 @@ Labels hash.
 
 Returns all image data as a hashref (for JSON serialization).
 
+=head1 SEE ALSO
+
+=over 4
+
+=item * L<WWW::Hetzner::Cloud::API::Images> - Images API
+
+=item * L<WWW::Hetzner::Cloud> - Main Cloud API client
+
+=item * L<WWW::Hetzner::Cloud::Server> - Server entity
+
+=item * L<WWW::Hetzner> - Main umbrella module
+
+=back
+
 =head1 SUPPORT
 
 =head2 Issues
