@@ -1,8 +1,7 @@
 package WWW::Hetzner::Cloud::LoadBalancer;
-our $AUTHORITY = 'cpan:GETTY';
 # ABSTRACT: Hetzner Cloud Load Balancer object
 
-our $VERSION = '0.002';
+our $VERSION = '0.003';
 
 use Moo;
 use Carp qw(croak);
@@ -198,7 +197,8 @@ sub data {
 }
 
 
-1;
+
+1.
 
 __END__
 
@@ -212,7 +212,7 @@ WWW::Hetzner::Cloud::LoadBalancer - Hetzner Cloud Load Balancer object
 
 =head1 VERSION
 
-version 0.002
+version 0.003
 
 =head1 SYNOPSIS
 
@@ -382,6 +382,24 @@ Reloads load balancer data from the API.
 
 Returns all load balancer data as a hashref (for JSON serialization).
 
+=head1 SEE ALSO
+
+=over 4
+
+=item * L<WWW::Hetzner::Cloud::API::LoadBalancers> - Load Balancers API
+
+=item * L<WWW::Hetzner::Cloud> - Main Cloud API client
+
+=item * L<WWW::Hetzner::Cloud::Server> - Server entity
+
+=item * L<WWW::Hetzner::Cloud::Network> - Network entity
+
+=item * L<WWW::Hetzner::Cloud::Location> - Location entity
+
+=item * L<WWW::Hetzner> - Main umbrella module
+
+=back
+
 =head1 SUPPORT
 
 =head2 Issues
