@@ -1,8 +1,7 @@
 package WWW::Hetzner::Cloud::PlacementGroup;
-our $AUTHORITY = 'cpan:GETTY';
 # ABSTRACT: Hetzner Cloud Placement Group object
 
-our $VERSION = '0.002';
+our $VERSION = '0.003';
 
 use Moo;
 use Carp qw(croak);
@@ -69,7 +68,8 @@ sub data {
 }
 
 
-1;
+
+1.
 
 __END__
 
@@ -83,7 +83,7 @@ WWW::Hetzner::Cloud::PlacementGroup - Hetzner Cloud Placement Group object
 
 =head1 VERSION
 
-version 0.002
+version 0.003
 
 =head1 SYNOPSIS
 
@@ -148,6 +148,20 @@ Deletes the placement group.
 
 Returns all placement group data as a hashref (for JSON serialization).
 
+=head1 SEE ALSO
+
+=over 4
+
+=item * L<WWW::Hetzner::Cloud::API::PlacementGroups> - Placement Groups API
+
+=item * L<WWW::Hetzner::Cloud> - Main Cloud API client
+
+=item * L<WWW::Hetzner::Cloud::Server> - Server entity
+
+=item * L<WWW::Hetzner> - Main umbrella module
+
+=back
+
 =head1 SUPPORT
 
 =head2 Issues
