@@ -1,8 +1,7 @@
 package WWW::Hetzner::Cloud::PrimaryIP;
-our $AUTHORITY = 'cpan:GETTY';
 # ABSTRACT: Hetzner Cloud Primary IP object
 
-our $VERSION = '0.002';
+our $VERSION = '0.003';
 
 use Moo;
 use Carp qw(croak);
@@ -157,7 +156,8 @@ sub data {
 }
 
 
-1;
+
+1.
 
 __END__
 
@@ -171,7 +171,7 @@ WWW::Hetzner::Cloud::PrimaryIP - Hetzner Cloud Primary IP object
 
 =head1 VERSION
 
-version 0.002
+version 0.003
 
 =head1 SYNOPSIS
 
@@ -303,6 +303,22 @@ Reloads primary IP data from the API.
 
 Returns all primary IP data as a hashref (for JSON serialization).
 
+=head1 SEE ALSO
+
+=over 4
+
+=item * L<WWW::Hetzner::Cloud::API::PrimaryIPs> - Primary IPs API
+
+=item * L<WWW::Hetzner::Cloud> - Main Cloud API client
+
+=item * L<WWW::Hetzner::Cloud::Server> - Server entity
+
+=item * L<WWW::Hetzner::Cloud::Datacenter> - Datacenter entity
+
+=item * L<WWW::Hetzner> - Main umbrella module
+
+=back
+
 =head1 SUPPORT
 
 =head2 Issues
