@@ -1,8 +1,7 @@
 package WWW::Hetzner::Cloud::SSHKey;
-our $AUTHORITY = 'cpan:GETTY';
 # ABSTRACT: Hetzner Cloud SSHKey object
 
-our $VERSION = '0.002';
+our $VERSION = '0.003';
 
 use Moo;
 use Carp qw(croak);
@@ -68,7 +67,8 @@ sub data {
 }
 
 
-1;
+
+1.
 
 __END__
 
@@ -82,7 +82,7 @@ WWW::Hetzner::Cloud::SSHKey - Hetzner Cloud SSHKey object
 
 =head1 VERSION
 
-version 0.002
+version 0.003
 
 =head1 SYNOPSIS
 
@@ -150,6 +150,20 @@ Deletes the SSH key.
 
 Returns all SSH key data as a hashref (for JSON serialization).
 
+=head1 SEE ALSO
+
+=over 4
+
+=item * L<WWW::Hetzner::Cloud::API::SSHKeys> - SSH Keys API
+
+=item * L<WWW::Hetzner::Cloud> - Main Cloud API client
+
+=item * L<WWW::Hetzner::Cloud::Server> - Server entity
+
+=item * L<WWW::Hetzner> - Main umbrella module
+
+=back
+
 =head1 SUPPORT
 
 =head2 Issues
