@@ -1,8 +1,7 @@
 package WWW::Hetzner::Cloud::ServerType;
-our $AUTHORITY = 'cpan:GETTY';
 # ABSTRACT: Hetzner Cloud ServerType object
 
-our $VERSION = '0.002';
+our $VERSION = '0.003';
 
 use Moo;
 use namespace::clean;
@@ -58,7 +57,8 @@ sub data {
 }
 
 
-1;
+
+1.
 
 __END__
 
@@ -72,7 +72,7 @@ WWW::Hetzner::Cloud::ServerType - Hetzner Cloud ServerType object
 
 =head1 VERSION
 
-version 0.002
+version 0.003
 
 =head1 SYNOPSIS
 
@@ -133,6 +133,20 @@ Deprecation timestamp if deprecated, undef otherwise.
 
 Returns all server type data as a hashref (for JSON serialization).
 
+=head1 SEE ALSO
+
+=over 4
+
+=item * L<WWW::Hetzner::Cloud::API::ServerTypes> - Server Types API
+
+=item * L<WWW::Hetzner::Cloud> - Main Cloud API client
+
+=item * L<WWW::Hetzner::Cloud::Server> - Server entity
+
+=item * L<WWW::Hetzner> - Main umbrella module
+
+=back
+
 =head1 SUPPORT
 
 =head2 Issues
