@@ -1,8 +1,7 @@
 package WWW::Hetzner::Cloud::Zone;
-our $AUTHORITY = 'cpan:GETTY';
 # ABSTRACT: Hetzner Cloud DNS Zone object
 
-our $VERSION = '0.002';
+our $VERSION = '0.003';
 
 use Moo;
 use Carp qw(croak);
@@ -100,7 +99,8 @@ sub data {
 }
 
 
-1;
+
+1.
 
 __END__
 
@@ -114,7 +114,7 @@ WWW::Hetzner::Cloud::Zone - Hetzner Cloud DNS Zone object
 
 =head1 VERSION
 
-version 0.002
+version 0.003
 
 =head1 SYNOPSIS
 
@@ -214,6 +214,22 @@ Exports the zone as a standard zone file format.
 
 Returns all zone data as a hashref (for JSON serialization).
 
+=head1 SEE ALSO
+
+=over 4
+
+=item * L<WWW::Hetzner::Cloud::API::Zones> - Zones API
+
+=item * L<WWW::Hetzner::Cloud::API::RRSets> - DNS records API
+
+=item * L<WWW::Hetzner::Cloud> - Main Cloud API client
+
+=item * L<WWW::Hetzner::Cloud::RRSet> - DNS record entity
+
+=item * L<WWW::Hetzner> - Main umbrella module
+
+=back
+
 =head1 SUPPORT
 
 =head2 Issues
